==> Banners-2.3.7.tar.gz: Banners/lang/ext/de_DE.php <==
<?php
$lang['help_param_action'] = 'Specify the behaviour of the module.  Possible values are &quot;default&quot; and &quot;list&quot;.  The default action is used for displaying a single banner according to specified criterium.  The list action is used to display all of the banners of a specified category or category id';
$lang['help_param_category'] = 'In the default action, this parameter is used to specify the name of the category from which a single banner will be displayed.  In the list action this parameter is required to specify the name of the category from which all banners will be displayed';
$lang['help_param_mode'] = 'This parameter is only used in the default action, it specifies the way in which banners are selected from the specified category.  The only value is &quot;sequential&quot; which indicates that the module should choose the next non expired banner with the least amount of impressions.  Not specifying this parameter will result in a random banner being selected';
$lang['help_param_name'] = 'This parameter is only used in the default action.  It specifies an absolute name of a banner to load.  However, if the banner is invalid (the number of impressions has been reached, OR it has expired), nothing will be returned.';
$lang['bannerlist_template'] = 'Banner List Template';
$lang['info_bannerlist_template'] = 'Used with the list action, this template controls the dispay of all banners in the selected category';
$lang['none'] = 'None';
$lang['error_invalid_dates'] = 'Fehler: Falsches Datum';
$lang['editbanner'] = 'Banner bearbeiten';
$lang['start_date'] = 'Startdatum';
$lang['atttext'] = 'um';
$lang['template'] = 'Template ';
$lang['default_template'] = 'Standard-Kategorien-Template';
$lang['reset_template'] = 'Template auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
$lang['error_banners'] = 'Keine Banner vorhanden';
$lang['error_bannerexists'] = 'Ein Banner mit diesem Namen existiert bereits.';
$lang['accessdenied'] = 'Zugriff verweigert. Bitte pr&uuml;fen Sie Ihre Berechtigungen.';
$lang['addbanner'] = 'Banner hinzuf&uuml;gen';
$lang['addcategory'] = 'Kategorie hinzuf&uuml;gen';
$lang['areyousure'] = 'Wollen Sie das wirklich?';
$lang['banners'] = 'Banner';
$lang['cancel'] = 'Abbrechen';
$lang['categories'] = 'Kategorien';
$lang['category'] = 'Kategorie';
$lang['created'] = 'Erstellt';
$lang['date'] = 'Datum';
$lang['delete'] = 'L&ouml;schen';
$lang['description'] = 'Beschreibung';
$lang['edit'] = 'Bearbeiten';
$lang['editcategory'] = 'Kategorie bearbeiten';
$lang['error'] = 'Fehler!';
$lang['error_banerexists'] = 'Ein Banner mit diesem Namen existiert bereits!';
$lang['error_categorynotempty'] = 'Fehler: Die Kategorie ist nicht leer!';
$lang['error_dberror'] = 'Fehler: Datenbankfehler!';
$lang['error_emptybannername'] = 'Fehler: Der Bannername fehlt!';
$lang['error_emptycategory'] = 'Fehler: Die Kategorie fehlt!';
$lang['error_insufficientparams'] = 'Fehler: Mangelhafte Eingabe';
$lang['error_nocategories'] = 'Fehler: Keine Kategorien gefunden';
$lang['error_noresults'] = 'F&uuml;r diese Abfrage wurden keine Banner gefunden.';
$lang['error_textorimage'] = 'Legen Sie entweder die URL und ein BILD oder einen TEXT fest, aber nicht beides.';
$lang['expires'] = 'Ablauf';
$lang['friendlyname'] = 'Banner verwalten';
$lang['height'] = 'H&ouml;he';
$lang['hits'] = 'Zugriffe';
$lang['href_text'] = 'Linktext';
$lang['id'] = 'ID ';
$lang['image'] = 'Bild';
$lang['image_text'] = 'Alternativer Bildtext';
$lang['impressions'] = 'Aufrufe';
$lang['info_href_text'] = 'Zus&auml;tzlicher Text f&uuml;r den Link-Tag. Dieser Text wird direkt im Link-Tag eingef&uuml;gt.';
$lang['info_image'] = 'Legen Sie eine Datei relativ zu ihrem /uploads Verzeichnis fest';
$lang['info_image_text'] = 'Zus&auml;tzlicher Text f&uuml;r den Bild-Tag';
$lang['info_max_hits'] = 'Verwenden sie 0 f&uuml;r unbeschr&auml;nkte Zugriffe';
$lang['info_max_impressions'] = 'Verwenden sie 0 f&uuml;r unbeschr&auml;nkte Aufrufe';
$lang['installed'] = 'Modulversion %s installiert.';
$lang['ipaddress'] = 'IP-Adresse';
$lang['max_hits'] = 'Maximale Zugriffe';
$lang['max_impressions'] = 'Maximale Aufrufe';
$lang['name'] = 'Name ';
$lang['never'] = 'Niemals';
$lang['postinstall'] = 'Stellen Sie sicher, dass Benutzer, die mit Banners-Modul arbeiten sollen, die Berechtigung &quot;Manage Banners&quot; haben!';
$lang['postuninstall'] = 'Das Banners-Modul wurde deinstalliert und die Datenbanktabellen gel&ouml;scht. Schade, Sie gehen zu sehen ...';
$lang['preferences'] = 'Einstellungen';
$lang['prefsupdated'] = 'Moduleinstellungen aktualisiert.';
$lang['prompt_categorydesc'] = 'Beschreibung der Kategorie';
$lang['prompt_categoryname'] = 'Name der Kategorie';
$lang['prompt_imageheight'] = 'Bildh&ouml;he';
$lang['prompt_imagewidth'] = 'Bildbreite';
$lang['prompt_subnet_exclusions'] = 'Diese Subnets von der statistischen Erfassung ausschlie&szlig;en';
$lang['prompt_upload_category'] = 'Kategorie (Uploads-Modul)';
$lang['prompt_upload_file'] = 'Bild (Uploads-Modul)';
$lang['selectcategory'] = 'Kategorie ausw&auml;hlen';
$lang['submit'] = 'Absenden';
$lang['text'] = 'Text ';
$lang['title_mod_admin'] = 'Modul-Administration';
$lang['title_mod_prefs'] = 'Moduleinstellungen';
$lang['uninstalled'] = 'Modul deinstalliert.';
$lang['upgraded'] = 'Modul auf Version %s aktualisiert.';
$lang['url'] = 'URL ';
$lang['width'] = 'Breite';
$lang['title_admin_panel'] = 'Banners-Modul';
$lang['moddescription'] = 'Ein Modul zur Verwaltung wechselnder Banner';
$lang['welcome_text'] = '<p>Willkommen in der Administration des Moduls zur Bannerverwaltung.</p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 August 2005. Initial Release.</li>
<li>Version 2.0. September 2005. Initial Release for 0.1..</li>
<li>Version 2.0.1. September 2005. Display sample banner in the edit banner page, added name= parameter, and made subnet exclusions work.  Also changed the definition of the database to allow for additional text in the link and image tags.</li>
<li>Version 2.0.2. September 2005. Added integration with the uploads module (1.0.6) so that we can get lits of files for banners, etc.  The banners module is still optional though.</li>
<li>Version 2.0.3. September 2005. Fixed a very minor issue with never expires..</li>
<li>Version 2.0.4. September 2005. Fixed a very minor issue with module dependencies, and a big bug in the database spec if you did a scratch install.</li>
<li>Version 2.0.5. October 2005. Add coments around the output</li>
<li>Version 2.0.6. December 2005. Minor validation fixes, description is now output between the <img>and</img> tags, and an alt attribute is in the img tag.</li>
<li>Version 2.0.7. January 2006. More validation fixes, Moved the admin tabs around, fixed an issue where you could almost create a banner without defining a category, and... fixed the expiry date issue for good (hopefully).</li>
<li>Version 2.1.0. August 2006. Prepared for 1.0 compatibility, split into multiple files, used references where possible, improved messages, and a general cleanup.</li>
<li>Version 2.2. March 2008. 
    <p>The first release in a long while this fixes issues with the date fields, and the expiry date.  Also integrates changes so that the active tab is maintaned (DeeEye) and changes the license.</p>
    <p>Now require CMS 1.2.3 or greater</p>
</li>
<li>Version 2.2.1. April 2008.
    <p>Minor fixes.</p>
</li>
<li>Version 2.2.3. April 2009.
    <p>Remove the width and height parameters, add a start date, and now use templates... major overhaul.</p>
</li>
<li>Version 2.3 - September 2009.
  <ul>
    <li>Major cleanup of code</li>
    <li>Get rid of the never expire stuff... people can just use a really long date.</li>
    <li>Dont ask for input of times any more... just use days</li>
    <li>Fixed to work with newest version of uploads, if it can be found.</li>
    <li>Now depends on CGExtensions</li>
    <li>Adds the banner list action.</li>
  </ul>
</li>
<li>Version 2.3.1 - September 2009.
  <ul>
    <li>Bug Fixes.</li>
  </ul>
</li>
<li>Version 2.3.2 - October 2009.
  <ul>
    <li>Minor Bug Fixes.</li>
  </ul>
</li>
</ul>';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Mit dem Banners-Modul k&ouml;nnen verschiedene Banner-Kategorien, Zugriffe, Aufrufe und Ablaufdaten verwaltet werden. Auch eine Zufallsauswahl aus allen verf&uuml;gbaren und g&uuml;ltigen Bannern ist m&ouml;glich.</p>
<h3>Wie wird es eingesetzt ?</h3>
<p>Um das Modul zu verwenden, f&uuml;gen Sie den Aufruf {cms_module module=&#039;Banners&#039; category=&#039;Kategorie-Name&#039;} in Ihre Seite oder Template ein.</p> 
<p>Au&szlig;erdem m&uuml;ssen die Banner in ein entsprechendes Verzeichnis innerhalb des /uploads Verzeichnisses hochgeladen und dann in der Administration zur Datenbank hinzugef&uuml;gt werden.</p>
<h3>Parameter</h3>
<ul>
<li><em>(ERFORDERLICH)</em> category=&quot;Kategorie&quot; = zuf&auml;llige Auswahl aus allen in dieser Kategorie verf&uuml;gbaren Banner</li>
<li><em>(optional)</em> name=&quot;Name&quot; = nur das Banner mit diesem Namen ist ausgew&auml;hlt</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Anstatt einer zuf&auml;lligen Auswahl an g&uuml;ltigen Bannern , wird eines mit den geringsten Zugriffen ausgew&auml;hlt.</li>
</ul>
<h4>Hinweis</h4>
<p>Das Uploads-Modul und das Banners-Modul arbeiten gut zusammen. So k&ouml;nnen sie im Uploads-Modul eine &quot;Banner&quot;-Kategorie erstellen und die Banner (Bilder) dort hinein laden. Im Banners-Modul m&uuml;ssen Sie dann nur noch das Banner mit dem Pfad &quot;banner/<dateiname>&quot; hinzuf&uuml;gen.</p>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen sie bitte die Projektseite unter <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>

<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2008, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA</p>';
$lang['utma'] = '156861353.717462736.1147511856.1262804461.1262810750.400';
$lang['utmz'] = '156861353.1262560100.393.7.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/projects/gallery|utmcmd=referral';
$lang['qca'] = '1246469815-37371011-11931623';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Banners-2.6.tar.gz: Banners/lang/ext/de_DE.php <==
<?php
$lang['statreport_linesperpage'] = 'Zeilen pro Seite f&uuml;r den Statistik-Bericht';
$lang['banner'] = 'Bannerwerbung';
$lang['of'] = 'von';
$lang['page'] = 'Seite';
$lang['generated'] = 'Erstellt';
$lang['generated_by'] = 'Erstellt von';
$lang['desc_stats_report'] = 'Ein Bericht zur Veranschaulichung der Anzahl der Impressionen und Click-Through-Hits aus den Banner-Modul';
$lang['title_stats_report'] = 'Banner Statistik Report';
$lang['view_statistics'] = 'Statistiken anzeigen';
$lang['msg_new_window'] = 'Erstellt ein neues Fenster';
$lang['statreport_template'] = 'Statistik Berichts-Template';
$lang['your_ad_here'] = 'Hier k&ouml;nnte Ihre Werbung sein';
$lang['prompt_dflt_image'] = 'Voreingestelltes Bild';
$lang['prompt_dflt_url'] = 'Standard-URL';
$lang['info_dflt_image'] = 'Geben Sie einen Bild-Namen (bezogen auf das Uploads-Verzeichnis) eines zu verwendenden Bildes, wenn keine g&uuml;ltige Banner angezeigt werden';
$lang['prompt_hidefrombots'] = 'Robots Aufruf-Z&auml;hlung  ausschlie&szlig;en';
$lang['help_param_action'] = 'Legen Sie das Verhalten des Moduls fest. M&ouml;gliche Werte sind &quot;default&quot; und &quot;list&quot;. Die Standard-Aktion wird f&uuml;r die Anzeige von einem einzigen Banner nach vorgegebenen Kriterium verwendet. Die Liste Aktion dient zur Anzeige aller Banner einer bestimmten Kategorie oder Kategorie-ID';
$lang['help_param_category'] = 'In der Standard-Aktion, wird dieser Parameter verwendet, um den Namen der Kategorie, von denen ein einziges Banner angezeigt werden soll festzulegen. In der Liste-Aktion ist dieser Parameter erforderlich, um den Namen der Kategorie, von der alle Banner angezeigt wird, zu bestimmen';
$lang['help_param_mode'] = 'Dieser Parameter wird nur in die Standard-Aktion verwendet, es legt die Art fest, wie Banner aus der angegebenen Kategorie ausgew&auml;hlt werden. Der einzige Wert ist &quot;sequential&quot;, welches darauf hinweist, dass das Modul den n&auml;chsten nicht abgelaufenen Banner mit der geringsten Menge von Eindr&uuml;cken w&auml;hlen sollte. Beim nicht angeben dieses Parameters werden Banner in zuf&auml;lliger reihenfolge ausgew&auml;hlt';
$lang['help_param_name'] = 'Dieser Parameter wird nur in die Standard-Aktion verwendet. Es legt einen absoluten Namen eines Banners zum laden fest. Allerdings, wenn das Banner ung&uuml;ltig (die Anzahl der Impressionen erzielt worden ist, oder abgelaufen ist), wird nichts zur&uuml;ckgegeben werden.';
$lang['bannerlist_template'] = 'Banner Listen-Template';
$lang['info_bannerlist_template'] = 'Wird mit der Liste Aktion verwendet, diese Vorlage steuert die Anzeige aller Banner in der ausgew&auml;hlten Kategorie';
$lang['none'] = 'Keine';
$lang['error_invalid_dates'] = 'Fehler: Falsches Datum';
$lang['editbanner'] = 'Banner bearbeiten';
$lang['start_date'] = 'Startdatum';
$lang['atttext'] = 'um';
$lang['template'] = 'Template ';
$lang['default_template'] = 'Standard-Kategorien-Template';
$lang['reset_template'] = 'Template auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
$lang['error_banners'] = 'Keine Banner vorhanden';
$lang['error_bannerexists'] = 'Ein Banner mit diesem Namen existiert bereits.';
$lang['accessdenied'] = 'Zugriff verweigert. Bitte pr&uuml;fen Sie Ihre Berechtigungen.';
$lang['addbanner'] = 'Banner hinzuf&uuml;gen';
$lang['addcategory'] = 'Kategorie hinzuf&uuml;gen';
$lang['areyousure'] = 'Wollen Sie das wirklich?';
$lang['banners'] = 'Banner';
$lang['cancel'] = 'Abbrechen';
$lang['categories'] = 'Kategorien';
$lang['category'] = 'Kategorie';
$lang['created'] = 'Erstellt';
$lang['date'] = 'Datum';
$lang['delete'] = 'L&ouml;schen';
$lang['description'] = 'Beschreibung';
$lang['edit'] = 'Bearbeiten';
$lang['editcategory'] = 'Kategorie bearbeiten';
$lang['error'] = 'Fehler!';
$lang['error_banerexists'] = 'Ein Banner mit diesem Namen existiert bereits!';
$lang['error_categorynotempty'] = 'Fehler: Die Kategorie ist nicht leer!';
$lang['error_dberror'] = 'Fehler: Datenbankfehler!';
$lang['error_emptybannername'] = 'Fehler: Der Bannername fehlt!';
$lang['error_emptycategory'] = 'Fehler: Die Kategorie fehlt!';
$lang['error_insufficientparams'] = 'Fehler: Mangelhafte Eingabe';
$lang['error_nocategories'] = 'Fehler: Keine Kategorien gefunden';
$lang['error_noresults'] = 'F&uuml;r diese Abfrage wurden keine Banner gefunden.';
$lang['error_textorimage'] = 'Legen Sie entweder die URL und ein BILD oder einen TEXT fest, aber nicht beides.';
$lang['expires'] = 'Ablauf';
$lang['friendlyname'] = 'Banner verwalten';
$lang['height'] = 'H&ouml;he';
$lang['hits'] = 'Zugriffe';
$lang['href_text'] = 'Linktext';
$lang['id'] = 'ID ';
$lang['image'] = 'Bild';
$lang['image_text'] = 'Alternativer Bildtext';
$lang['impressions'] = 'Aufrufe';
$lang['info_href_text'] = 'Zus&auml;tzlicher Text f&uuml;r den Link-Tag. Dieser Text wird direkt im Link-Tag eingef&uuml;gt.';
$lang['info_image'] = 'Legen Sie eine Datei relativ zu ihrem /uploads Verzeichnis fest';
$lang['info_image_text'] = 'Zus&auml;tzlicher Text f&uuml;r den Bild-Tag';
$lang['info_max_hits'] = 'Verwenden sie 0 f&uuml;r unbeschr&auml;nkte Zugriffe';
$lang['info_max_impressions'] = 'Verwenden sie 0 f&uuml;r unbeschr&auml;nkte Aufrufe';
$lang['installed'] = 'Modulversion %s installiert.';
$lang['ipaddress'] = 'IP-Adresse';
$lang['max_hits'] = 'Maximale Zugriffe';
$lang['max_impressions'] = 'Maximale Aufrufe';
$lang['name'] = 'Name ';
$lang['never'] = 'Niemals';
$lang['postinstall'] = 'Stellen Sie sicher, dass Benutzer, die mit Banners-Modul arbeiten sollen, die Berechtigung &quot;Manage Banners&quot; haben!';
$lang['postuninstall'] = 'Das Banners-Modul wurde deinstalliert und die Datenbanktabellen gel&ouml;scht. Schade, Sie gehen zu sehen ...';
$lang['preferences'] = 'Einstellungen';
$lang['prefsupdated'] = 'Moduleinstellungen aktualisiert.';
$lang['prompt_categorydesc'] = 'Beschreibung der Kategorie';
$lang['prompt_categoryname'] = 'Name der Kategorie';
$lang['prompt_imageheight'] = 'Bildh&ouml;he';
$lang['prompt_imagewidth'] = 'Bildbreite';
$lang['prompt_subnet_exclusions'] = 'Diese Subnets von der statistischen Erfassung ausschlie&szlig;en';
$lang['prompt_upload_category'] = 'Kategorie (Uploads-Modul)';
$lang['prompt_upload_file'] = 'Bild (Uploads-Modul)';
$lang['selectcategory'] = 'Kategorie ausw&auml;hlen';
$lang['submit'] = 'Absenden';
$lang['text'] = 'Text ';
$lang['title_mod_admin'] = 'Modul-Administration';
$lang['title_mod_prefs'] = 'Moduleinstellungen';
$lang['uninstalled'] = 'Modul deinstalliert.';
$lang['upgraded'] = 'Modul auf Version %s aktualisiert.';
$lang['url'] = 'URL ';
$lang['width'] = 'Breite';
$lang['title_admin_panel'] = 'Banners-Modul';
$lang['moddescription'] = 'Ein Modul zur Verwaltung wechselnder Banner';
$lang['welcome_text'] = '<p>Willkommen in der Administration des Moduls zur Bannerverwaltung.</p>';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Mit dem Banners-Modul k&ouml;nnen verschiedene Banner-Kategorien, Zugriffe, Aufrufe und Ablaufdaten verwaltet werden. Auch eine Zufallsauswahl aus allen verf&uuml;gbaren und g&uuml;ltigen Bannern ist m&ouml;glich.</p>
<h3>Wie wird es eingesetzt ?</h3>
<p>Um das Modul zu verwenden, f&uuml;gen Sie den Aufruf {cms_module module=&#039;Banners&#039; category=&#039;Kategorie-Name&#039;} in Ihre Seite oder Template ein.</p> 
<p>Au&szlig;erdem m&uuml;ssen die Banner in ein entsprechendes Verzeichnis innerhalb des /uploads Verzeichnisses hochgeladen und dann in der Administration zur Datenbank hinzugef&uuml;gt werden.</p>
<h3>Parameter</h3>
<ul>
<li><em>(ERFORDERLICH)</em> category=&quot;Kategorie&quot; = zuf&auml;llige Auswahl aus allen in dieser Kategorie verf&uuml;gbaren Banner</li>
<li><em>(optional)</em> name=&quot;Name&quot; = nur das Banner mit diesem Namen ist ausgew&auml;hlt</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Anstatt einer zuf&auml;lligen Auswahl an g&uuml;ltigen Bannern , wird eines mit den geringsten Zugriffen ausgew&auml;hlt.</li>
</ul>
<h4>Hinweis</h4>
<p>Das Uploads-Modul und das Banners-Modul arbeiten gut zusammen. So k&ouml;nnen sie im Uploads-Modul eine &quot;Banner&quot;-Kategorie erstellen und die Banner (Bilder) dort hinein laden. Im Banners-Modul m&uuml;ssen Sie dann nur noch das Banner mit dem Pfad &quot;banner/<dateiname>&quot; hinzuf&uuml;gen.</p>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen sie bitte die Projektseite unter <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor calguy1000, ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>

<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2008, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA</p>';
$lang['qca'] = 'P0-1458450664-1284573084918';
$lang['utmz'] = '156861353.1301074204.33.55.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utma'] = '156861353.1403231767.1300657837.1301091815.1301122726.38';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1301122726';
?>
